"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fns_1 = require("./fns");
const utilfns_1 = require("./utilfns");
const inquirer_1 = require("inquirer");
const chalk_1 = require("chalk");
const cli_spinner_1 = require("cli-spinner");
const log = console.log;
const cwd = process.cwd();
exports.split = () => {
    const pdfFiles = fns_1.getPathsForSpecificExtensions(cwd, [".pdf"]);
    if (pdfFiles.length === 0) {
        log(chalk_1.default.bgRed("No input pdf files found"));
        process.exit();
    }
    const csvFiles = fns_1.getPathsForSpecificExtensions(cwd, [".csv", ".txt"]);
    const paretFolder = pdfFiles[0].parent;
    const questions = [
        {
            name: "inputFile",
            type: "list",
            choices: [...pdfFiles.map((pth) => pth.basename + pth.ext)],
            message: "choose the input file?",
            filter: v => pdfFiles
                .filter((vv) => vv.basename + vv.ext === v)
                .map((pth) => pth.path)[0]
        },
        {
            name: "numPages",
            type: "input",
            message: "type number of pages to split the file.",
            default: "2"
        },
        {
            name: "dataFile",
            type: "list",
            choices: [
                "new",
                ...csvFiles.map((pth) => pth.basename + pth.ext)
            ],
            message: "choose the source (csv or txt) of naming your output files (one column with no header).",
            filter: v => v === "new"
                ? ""
                : csvFiles
                    .filter((vv) => vv.basename + vv.ext === v)
                    .map((pth) => pth.path)[0]
        },
        {
            name: "csvUserDefined",
            type: "input",
            message: "type the string that will be used for naming your output files.",
            default: "output",
            when: answers => answers["dataFile"] === ""
        },
        {
            name: "outputNamePrefix",
            type: "input",
            message: "type the prefix of to be used in naming your split pdf files.",
            default: "output_"
        },
        {
            name: "outputNameSuffix",
            type: "input",
            message: "type the suffix of to be used in naming your split pdf files.",
            default: ""
        },
        {
            name: "outputDir",
            type: "input",
            message: "type the string that will be used to save your output files.",
            default: "output_files",
            filter: v => v
                .replace(/\\/g, "/")
                .split("/")
                .reduce((vv1, vv2) => [
                ...vv1,
                (vv1[vv1.length - 1] || "") + "/" + vv2
            ], [])
                .map((pth) => paretFolder + pth)
        }
    ];
    inquirer_1.prompt(questions).then(async ({ inputFile, dataFile, outputDir, numPages, csvUserDefined, outputNamePrefix, outputNameSuffix }) => {
        const opts = {
            inputFile,
            dataFile: csvUserDefined === "new" ? "" : dataFile,
            outputDir,
            numPages,
            outputNamePrefix,
            outputNameSuffix
        };
        const spinner = new cli_spinner_1.Spinner(chalk_1.default.magentaBright("%s Your file is being split. Please wait ..."));
        spinner.start();
        utilfns_1.init(opts)
            .then(() => {
            spinner.stop();
            process.stdout.write("\n");
            log(chalk_1.default.green(" Done."));
        })
            .catch(err => {
            spinner.stop();
            process.stdout.write("\n");
            log(chalk_1.default.red("\n " + err));
        });
    });
};
